"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwaysai_user_email_cli_input_1 = require("./alwaysai-user-email-cli-input");
const alwayscli_1 = require("@alwaysai/alwayscli");
const run_and_catch_1 = require("@carnesen/run-and-catch");
describe(__filename, () => {
    it('parses a valid email', async () => {
        const VALID_EMAIL = 'me@example.com';
        const value = await alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput.getValue([VALID_EMAIL]);
        expect(value).toBe(VALID_EMAIL);
    });
    it('returns undefined on undefined', async () => {
        const value = await alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput.getValue(undefined);
        expect(value).toBe(undefined);
    });
    it('throws CLI_USAGE_ERROR error "single" if more than one value is passed', async () => {
        const exception = await run_and_catch_1.runAndCatch(alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput.getValue, [
            'foo',
            'bar',
        ]);
        expect(exception.code).toBe(alwayscli_1.CLI_USAGE_ERROR);
        expect(exception.message).toMatch(/single/);
    });
    it('throws CLI_USAGE_ERROR error "address" if more than one value is passed', async () => {
        const exception = await run_and_catch_1.runAndCatch(alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput.getValue, ['']);
        expect(exception.code).toBe(alwayscli_1.CLI_USAGE_ERROR);
        expect(exception.message).toMatch(/address/);
    });
    it('throws CLI_TERSE_ERROR error "not a valid email" if more than one value is passed', async () => {
        const exception = await run_and_catch_1.runAndCatch(alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput.getValue, ['foo']);
        expect(exception.code).toBe(alwayscli_1.CLI_TERSE_ERROR);
        expect(exception.message).toMatch(/not a valid email/);
    });
    it('has an appropriate description', () => {
        expect(alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput.description).toMatch(/email address/i);
    });
});
//# sourceMappingURL=alwaysai-user-email-cli-input.test.js.map