"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const target_protocol_1 = require("../util/target-protocol");
const target_json_prompt_component_1 = require("./target-json-prompt-component");
const environment_1 = require("../environment");
const destination_prompt_component_1 = require("./destination-prompt-component");
const constants_1 = require("../constants");
const app_configure_preliminary_steps_component_1 = require("./app-configure-preliminary-steps-component");
const remove_target_json_file_component_1 = require("./remove-target-json-file-component");
async function appConfigurePromptComponent(props) {
    const yes = false;
    const { targetHostname, targetPath, targetProtocol } = props;
    await app_configure_preliminary_steps_component_1.appConfigurePreliminaryStepsComponent({ yes });
    switch (environment_1.ALWAYSAI_OS_PLATFORM) {
        case 'linux': {
            // Note: We do not yet support ALWAYSAI_HOME on linux
            await target_json_prompt_component_1.targetJsonPromptComponent({
                targetProtocol,
                targetHostname,
                targetPath,
            });
            break;
        }
        case 'win32':
        case 'darwin':
        default: {
            if (!environment_1.ALWAYSAI_HOME) {
                await target_json_prompt_component_1.targetJsonPromptComponent({
                    targetProtocol,
                    targetHostname,
                    targetPath,
                });
            }
            else {
                // ALWAYSAI_HOME is defined
                const destination = await destination_prompt_component_1.destinationPromptComponent({
                    destination: targetProtocol === target_protocol_1.TargetProtocol['ssh+docker:']
                        ? destination_prompt_component_1.Destination.REMOTE_DEVICE
                        : destination_prompt_component_1.Destination.YOUR_LOCAL_COMPUTER,
                });
                switch (destination) {
                    case destination_prompt_component_1.Destination.YOUR_LOCAL_COMPUTER: {
                        await remove_target_json_file_component_1.removeTargetJsonFileComponent();
                        break;
                    }
                    case destination_prompt_component_1.Destination.REMOTE_DEVICE: {
                        await target_json_prompt_component_1.targetJsonPromptComponent({
                            targetProtocol,
                            targetHostname,
                            targetPath,
                        });
                        break;
                    }
                    default: {
                        throw new Error(`Unexpected destination "${destination}". ${constants_1.PLEASE_REPORT_THIS_ERROR_MESSAGE}`);
                    }
                }
            }
        }
    }
}
exports.appConfigurePromptComponent = appConfigurePromptComponent;
//# sourceMappingURL=app-configure-prompt-component.js.map