"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const target_protocol_1 = require("../util/target-protocol");
const constants_1 = require("../constants");
const find_or_write_dockerfile_component_1 = require("./find-or-write-dockerfile-component");
const required_with_yes_message_1 = require("../util/required-with-yes-message");
const target_json_yes_component_1 = require("./target-json-yes-component");
const target_path_default_value_1 = require("../util/target-path-default-value");
const environment_1 = require("../environment");
const app_configure_preliminary_steps_component_1 = require("./app-configure-preliminary-steps-component");
const remove_target_json_file_component_1 = require("./remove-target-json-file-component");
const child_spawner_1 = require("../util/spawner/child-spawner");
const ssh_spawner_1 = require("../util/spawner/ssh-spawner");
async function appConfigureYesComponent(props) {
    const yes = true;
    const { targetHostname, targetPath, targetProtocol } = props;
    let targetHardware = 'generic';
    switch (targetProtocol) {
        case undefined: {
            if (!environment_1.ALWAYSAI_HOME) {
                throw new alwayscli_1.CliUsageError(`The --protocol option is required unless the environment variable ALWAYSAI_HOME is set to the location of an ${constants_1.ALWAYSAI_DESKTOP_SOFTWARE_NAME} installation.`);
            }
            if (targetHostname) {
                throw new alwayscli_1.CliUsageError(OnlyAllowedWithSshPlusDockerMessage('hostname'));
            }
            if (targetPath) {
                throw new alwayscli_1.CliUsageError(OnlyAllowedWithSshPlusDockerMessage('path'));
            }
            await remove_target_json_file_component_1.removeTargetJsonFileComponent();
            break;
        }
        case 'docker:': {
            await app_configure_preliminary_steps_component_1.appConfigurePreliminaryStepsComponent({ yes });
            await find_or_write_dockerfile_component_1.findOrWriteDockerfileComponent({ yes });
            const localUname = await child_spawner_1.ChildSpawner({ path: '.' }).run({
                exe: 'uname',
                args: ['-r'],
            });
            if (localUname.includes('tegra')) {
                targetHardware = 'nvidia';
            }
            await target_json_yes_component_1.targetJsonYesComponent({
                targetJson: {
                    targetProtocol,
                    dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                    targetHardware,
                },
            });
            break;
        }
        case 'ssh+docker:': {
            if (!targetHostname) {
                throw new alwayscli_1.CliUsageError(required_with_yes_message_1.RequiredWithYesMessage('hostname', undefined, `If "protocol" is "${target_protocol_1.TargetProtocol['ssh+docker:']}"`));
            }
            await app_configure_preliminary_steps_component_1.appConfigurePreliminaryStepsComponent({ yes });
            await find_or_write_dockerfile_component_1.findOrWriteDockerfileComponent({ yes });
            const externalUname = await ssh_spawner_1.SshSpawner({ targetHostname }).run({
                exe: 'uname',
                args: ['-r'],
            });
            if (externalUname.includes('tegra')) {
                targetHardware = 'nvidia';
            }
            await target_json_yes_component_1.targetJsonYesComponent({
                targetJson: {
                    targetProtocol,
                    targetHostname,
                    targetPath: targetPath || target_path_default_value_1.TargetPathDefaultValue(),
                    dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                    targetHardware,
                },
            });
            break;
        }
        default: {
            throw new Error(constants_1.PLEASE_REPORT_THIS_ERROR_MESSAGE);
        }
    }
}
exports.appConfigureYesComponent = appConfigureYesComponent;
function OnlyAllowedWithSshPlusDockerMessage(optionName) {
    return `The --${optionName} option is only allowed with --yes for --protocol "${target_protocol_1.TargetProtocol['ssh+docker:']}"`;
}
//# sourceMappingURL=app-configure-yes-component.js.map