"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const fs_1 = require("fs");
const target_json_file_1 = require("../util/target-json-file");
const js_spawner_1 = require("../util/spawner/js-spawner");
const run_with_spinner_1 = require("../util/run-with-spinner");
const constants_1 = require("../constants");
const target_json_prompt_component_1 = require("./target-json-prompt-component");
const connect_by_ssh_component_1 = require("./connect-by-ssh-component");
const create_target_directory_component_1 = require("./create-target-directory-component");
const clean_target_directory_component_1 = require("./clean-target-directory-component");
const confirm_write_file_prompt_component_1 = require("./confirm-write-file-prompt-component");
const build_docker_image_component_1 = require("./build-docker-image-component");
const find_or_write_private_key_file_component_1 = require("./find-or-write-private-key-file-component");
const app_copy_files_1 = require("../util/app-copy-files");
const spinner_1 = require("../util/spinner");
const app_install_preliminary_steps_component_1 = require("./app-install-preliminary-steps-component");
const app_install_models_component_1 = require("./app-install-models-component");
const ssh_docker_spawner_1 = require("../util/spawner/ssh-docker-spawner");
const path_1 = require("path");
async function appDeployComponent(props) {
    const { yes, clean } = props;
    await app_install_preliminary_steps_component_1.appInstallPreliminaryStepsComponent({ yes });
    if (!fs_1.existsSync(constants_1.DOCKERFILE)) {
        throw new alwayscli_1.CliTerseError(MissingFilePleaseRunAppConfigureMessage(constants_1.DOCKERFILE));
    }
    let ranTargetJsonPromptComponent = false;
    const targetJsonFile = target_json_file_1.TargetJsonFile();
    if (!targetJsonFile.exists()) {
        if (yes) {
            throw new alwayscli_1.CliTerseError(MissingFilePleaseRunAppConfigureMessage(constants_1.TARGET_JSON_FILE_NAME));
        }
        const confirmed = await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({
            fileName: undefined,
            description: 'Target configuration',
        });
        if (!confirmed) {
            throw new alwayscli_1.CliTerseError('Unable to proceed without a target configuration');
        }
        await target_json_prompt_component_1.targetJsonPromptComponent();
        ranTargetJsonPromptComponent = true;
    }
    const targetHostSpawner = targetJsonFile.readHostSpawner();
    const targetJson = targetJsonFile.read();
    const sourceSpawner = js_spawner_1.JsSpawner();
    // Protocol-specific installation steps
    switch (targetJson.targetProtocol) {
        case 'ssh+docker:': {
            const { targetHostname, targetPath } = targetJson;
            if (!ranTargetJsonPromptComponent) {
                // If we ran the targetJsonPromptComponent we can skip these checks
                await find_or_write_private_key_file_component_1.findOrWritePrivateKeyFileComponent({ yes });
                await connect_by_ssh_component_1.connectBySshComponent({ targetHostname });
                if (clean) {
                    await clean_target_directory_component_1.cleanTargetDirectoryComponent({ yes, targetHostname, targetPath });
                }
                await create_target_directory_component_1.createTargetDirectoryComponent({ targetHostname, targetPath });
            }
            const busyboxSpawner = ssh_docker_spawner_1.SshDockerSpawner({
                targetHostname,
                targetPath,
                dockerImageId: constants_1.DOCKER_TEST_IMAGE_ID,
            });
            await run_with_spinner_1.runWithSpinner(async () => {
                await app_copy_files_1.appCopyFiles(sourceSpawner, busyboxSpawner);
                await targetHostSpawner.run({
                    exe: 'docker',
                    args: [
                        'run',
                        '--rm',
                        '--workdir',
                        '/app',
                        '--volume',
                        '$(pwd):/app',
                        constants_1.DOCKER_TEST_IMAGE_ID,
                        'chown',
                        '-R',
                        '$(id -u ${USER}):$(id -g ${USER})',
                        '/app',
                    ],
                    cwd: '.',
                });
            }, [], 'Copy application to target');
        }
    }
    const dockerImageId = await build_docker_image_component_1.buildDockerImageComponent({ targetHostSpawner });
    targetJsonFile.update(targetJson => {
        targetJson.dockerImageId = dockerImageId;
    });
    const targetSpawner = targetJsonFile.readContainerSpawner();
    await app_install_models_component_1.appInstallModelsComponent(targetSpawner);
    const spinner = spinner_1.Spinner('Install python virtual environment');
    try {
        if (await targetSpawner.exists(constants_1.VENV_BIN_ACTIVATE)) {
            spinner.succeed('Found python virtual environment');
        }
        else {
            await targetSpawner.run({
                exe: 'virtualenv',
                args: ['--system-site-packages', constants_1.VENV],
                cwd: '.',
            });
            spinner.succeed();
        }
    }
    catch (exception) {
        spinner.fail();
        throw exception;
    }
    if (fs_1.existsSync(constants_1.PYTHON_REQUIREMENTS_FILE_NAME)) {
        await run_with_spinner_1.runWithSpinner(targetSpawner.run, [
            {
                exe: path_1.posix.join(constants_1.VENV, 'bin', 'pip'),
                args: ['install', '--requirement', constants_1.PYTHON_REQUIREMENTS_FILE_NAME],
                cwd: '.',
            },
        ], 'Install python dependencies');
    }
}
exports.appDeployComponent = appDeployComponent;
function MissingFilePleaseRunAppConfigureMessage(fileName) {
    return `Missing file "${fileName}". Please run \`alwaysai app configure\` to set up this directory as an alwaysAI application.`;
}
//# sourceMappingURL=app-deploy-component.js.map