"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const path_1 = require("path");
const fs_1 = require("fs");
const environment_1 = require("../environment");
const js_spawner_1 = require("../util/spawner/js-spawner");
const run_with_spinner_1 = require("../util/run-with-spinner");
const constants_1 = require("../constants");
const app_install_preliminary_steps_component_1 = require("./app-install-preliminary-steps-component");
const app_install_models_component_1 = require("./app-install-models-component");
const run_1 = require("../util/spawner-base/run");
const venv_executables_directory_name_1 = require("../util/venv-executables-directory-name");
async function appInstallComponent(props) {
    const { yes } = props;
    if ((!environment_1.ALWAYSAI_HOME || !path_1.isAbsolute(environment_1.ALWAYSAI_HOME)) &&
        environment_1.ALWAYSAI_OS_PLATFORM !== 'darwin') {
        throw new alwayscli_1.CliTerseError(`This command requires that ALWAYSAI_HOME is set in your environment to the absolute path of your ${constants_1.ALWAYSAI_DESKTOP_SOFTWARE_NAME} installation`);
    }
    await app_install_preliminary_steps_component_1.appInstallPreliminaryStepsComponent({ yes });
    await app_install_models_component_1.appInstallModelsComponent(js_spawner_1.JsSpawner());
    if (!fs_1.existsSync(path_1.join(constants_1.VENV, venv_executables_directory_name_1.VenvExecutablesDirectoryName()))) {
        // check platform win or mac
        // if win
        const pythonExecutablePath = environment_1.ALWAYSAI_OS_PLATFORM === 'win32'
            ? path_1.join(environment_1.ALWAYSAI_HOME || '', 'resources', 'app', 'python35', 'python')
            : path_1.join('/Applications', 'alwaysAI.app', 'Contents', 'Resources', 'app', 'Python', 'bin', 'python3');
        // if mac
        await run_with_spinner_1.runWithSpinner(run_1.run, [
            {
                exe: pythonExecutablePath,
                args: ['-m', constants_1.VENV, '--system-site-packages', constants_1.VENV],
                cwd: '.',
            },
        ], 'Install python virtual environment');
    }
    if (fs_1.existsSync(constants_1.PYTHON_REQUIREMENTS_FILE_NAME)) {
        await run_with_spinner_1.runWithSpinner(run_1.run, [
            {
                exe: path_1.join(constants_1.VENV, venv_executables_directory_name_1.VenvExecutablesDirectoryName(), 'pip'),
                args: ['install', '--requirement', constants_1.PYTHON_REQUIREMENTS_FILE_NAME],
            },
        ], 'Install python dependencies');
    }
}
exports.appInstallComponent = appInstallComponent;
//# sourceMappingURL=app-install-component.js.map