"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const app_json_file_1 = require("../util/app-json-file");
const echo_1 = require("../util/echo");
const check_user_is_logged_in_component_1 = require("./check-user-is-logged-in-component");
const rpc_client_1 = require("../util/rpc-client");
const download_model_package_to_cache_1 = require("../util/download-model-package-to-cache");
const model_package_cache_1 = require("../util/model-package-cache");
const spinner_1 = require("../util/spinner");
async function appModelsAddComponent(props) {
    const { yes, dir = process.cwd(), ids } = props;
    const appJsonFile = app_json_file_1.AppJsonFile(dir);
    appJsonFile.read();
    await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes });
    const fetched = [];
    for (const id of ids) {
        const spinner = spinner_1.Spinner(`Fetch model ${id}`);
        try {
            const { version } = await rpc_client_1.CliRpcClient().getModelVersion({ id });
            if (!model_package_cache_1.modelPackageCache.has(id, version)) {
                await download_model_package_to_cache_1.downloadModelPackageToCache(id, version);
            }
            fetched.push([id, version]);
            spinner.succeed();
        }
        catch (exception) {
            spinner.fail();
            if (exception.code === 'MODEL_VERSION_NOT_FOUND') {
                throw new alwayscli_1.CliTerseError(`Model not found: "${id}"`);
            }
            throw exception;
        }
    }
    fetched.forEach(([id, version]) => {
        appJsonFile.addModel(id, version);
    });
    echo_1.echo();
    echo_1.echo(appJsonFile.describeModels());
}
exports.appModelsAddComponent = appModelsAddComponent;
//# sourceMappingURL=app-models-add-component.js.map