"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const run_and_catch_1 = require("@carnesen/run-and-catch");
const tempy = require("tempy");
const app_json_file_1 = require("../util/app-json-file");
const rpc_client_1 = require("../util/rpc-client");
const app_models_add_component_1 = require("./app-models-add-component");
const model_package_cache_1 = require("../util/model-package-cache");
const alwayscli_1 = require("@alwaysai/alwayscli");
const random_string_1 = require("../util/random-string");
const authentication_client_1 = require("../util/authentication-client");
const EMPTY_MODEL_ID = 'alwaysai/squeezenet_v1.1';
describe(app_models_add_component_1.appModelsAddComponent.name, () => {
    jest.setTimeout(30000);
    const yes = true;
    it('big test of all the features', async () => {
        // Start with no models
        const dir = tempy.directory();
        const appJsonFile = app_json_file_1.AppJsonFile(dir);
        appJsonFile.write({ models: {} });
        const { username } = await authentication_client_1.CliAuthenticationClient().getInfo();
        // We'll add the "empty" model
        const { version } = await rpc_client_1.CliRpcClient().getModelVersion({ id: EMPTY_MODEL_ID });
        // Make sure it's not in the cache
        model_package_cache_1.modelPackageCache.remove(EMPTY_MODEL_ID, version);
        // Now add it
        await app_models_add_component_1.appModelsAddComponent({ yes, dir, ids: [EMPTY_MODEL_ID] });
        // Should now be in the json file and cached
        expect(appJsonFile.read().models).toEqual({
            [EMPTY_MODEL_ID]: version,
        });
        expect(model_package_cache_1.modelPackageCache.has(EMPTY_MODEL_ID, version)).toBe(true);
        // Error condition: model not found
        const exception = await run_and_catch_1.runAndCatch(app_models_add_component_1.appModelsAddComponent, {
            yes,
            dir,
            ids: [`${username}/${random_string_1.RandomString()}`],
        });
        expect(exception.code).toBe(alwayscli_1.CLI_TERSE_ERROR);
        expect(exception.message).toMatch(/model not found/i);
    });
});
//# sourceMappingURL=app-models-add-component.test.js.map