"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logSymbols = require("log-symbols");
const alwayscli_1 = require("@alwaysai/alwayscli");
const app_json_file_1 = require("../util/app-json-file");
const rpc_client_1 = require("../util/rpc-client");
const echo_1 = require("../util/echo");
const check_user_is_logged_in_component_1 = require("./check-user-is-logged-in-component");
const spinner_1 = require("../util/spinner");
async function appModelsUpdateComponent(props) {
    const { yes, dir = process.cwd() } = props;
    await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes });
    const appJsonFile = app_json_file_1.AppJsonFile(dir);
    const { models } = appJsonFile.read();
    const updates = [];
    if (!models || Object.keys(models).length === 0) {
        echo_1.echo('No models to update!');
    }
    else {
        const spinner = spinner_1.Spinner('Fetching model metadata');
        for (const [id, currentVersion] of Object.entries(models)) {
            try {
                const { version: latestVersion } = await rpc_client_1.CliRpcClient().getModelVersion({ id });
                if (currentVersion !== latestVersion) {
                    updates.push([id, currentVersion, latestVersion]);
                }
            }
            catch (exception) {
                spinner.fail();
                if (exception.code === 'MODEL_VERSION_NOT_FOUND') {
                    throw new alwayscli_1.CliTerseError(`Model not found: "${id}"`);
                }
                throw exception;
            }
        }
        spinner.succeed();
        if (updates.length === 0) {
            echo_1.echo(`${logSymbols.success} All models are already up to date!`);
        }
        else {
            echo_1.echo(`${logSymbols.success} Updated models`);
            updates.forEach(([id, currentVersion, nextVersion]) => {
                echo_1.echo(`    ${id} ${currentVersion} --> ${nextVersion}`);
                appJsonFile.addModel(id, nextVersion);
            });
        }
    }
}
exports.appModelsUpdateComponent = appModelsUpdateComponent;
//# sourceMappingURL=app-models-update-component.js.map