"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tempy = require("tempy");
const app_models_update_component_1 = require("./app-models-update-component");
const app_json_file_1 = require("../util/app-json-file");
const rpc_client_1 = require("../util/rpc-client");
const alwayscli_1 = require("@alwaysai/alwayscli");
const authentication_client_1 = require("../util/authentication-client");
const random_string_1 = require("../util/random-string");
const run_and_catch_1 = require("@carnesen/run-and-catch");
describe(app_models_update_component_1.appModelsUpdateComponent.name, () => {
    const yes = true;
    it('big test of all the features', async () => {
        const dir = tempy.directory();
        const appJsonFile = app_json_file_1.AppJsonFile(dir);
        const { username } = await authentication_client_1.CliAuthenticationClient().getInfo();
        // Does nothing if there are no models
        appJsonFile.write({ models: {} });
        await app_models_update_component_1.appModelsUpdateComponent({ yes, dir });
        expect(appJsonFile.read().models).toEqual({});
        const id = 'alwaysai/yolo_v2';
        appJsonFile.write({
            models: {
                [id]: -1,
            },
        });
        // Updates the version identifier for an existing model
        await app_models_update_component_1.appModelsUpdateComponent({ yes, dir });
        const { version } = await rpc_client_1.CliRpcClient().getModelVersion({ id });
        expect(appJsonFile.read().models[id]).toBe(version);
        // Operation is idempotent
        await app_models_update_component_1.appModelsUpdateComponent({ yes, dir });
        // Throws "model not found" if the model id does not exist
        appJsonFile.write({ models: { [`${username}/${random_string_1.RandomString()}`]: 1 } });
        const exception = await run_and_catch_1.runAndCatch(app_models_update_component_1.appModelsUpdateComponent, { yes, dir });
        expect(exception.code).toBe(alwayscli_1.CLI_TERSE_ERROR);
        expect(exception.message).toMatch(/model not found/i);
    });
});
//# sourceMappingURL=app-models-update-component.test.js.map