"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const app_json_file_1 = require("../util/app-json-file");
const target_json_file_1 = require("../util/target-json-file");
const constants_1 = require("../constants");
const environment_1 = require("../environment");
const run_foreground_1 = require("../util/spawner-base/run-foreground");
const fs_1 = require("fs");
const BASH_INITIAL_ARGS = ['-o', 'onecmd', '-O', 'huponexit', '-c'];
async function appStartComponent(props = {}) {
    const { noSuperuser, args = [] } = props;
    const appJsonFile = app_json_file_1.AppJsonFile();
    const appJson = appJsonFile.read();
    const startScript = appJson.scripts && appJson.scripts.start;
    if (!startScript) {
        throw new alwayscli_1.CliTerseError(`This application does not define a "start" script in its application configuration file "${constants_1.APP_JSON_FILE_NAME}"`);
    }
    const targetJsonFile = target_json_file_1.TargetJsonFile();
    const targetJson = targetJsonFile.readIfExists();
    let exitCode;
    const quotedArgsString = args.map(arg => `'${arg}'`).join(' ');
    if (targetJson) {
        const spawner = targetJsonFile.readContainerSpawner();
        const { targetProtocol, targetHardware } = targetJson;
        const tty = process.stdin.isTTY;
        switch (targetProtocol) {
            case 'docker:': {
                exitCode = await spawner.runForeground({
                    exe: '/bin/bash',
                    args: [
                        ...BASH_INITIAL_ARGS,
                        `. ${constants_1.VENV_BIN_ACTIVATE} && ${startScript} ${quotedArgsString}`,
                    ],
                    cwd: '.',
                    tty,
                    expose5000: true,
                    superuser: !noSuperuser,
                    targetHardware,
                });
                break;
            }
            // This case differs from "docker:"" only in the extra single quotes around the command
            case 'ssh+docker:': {
                exitCode = await spawner.runForeground({
                    exe: '/bin/bash',
                    args: [
                        ...BASH_INITIAL_ARGS,
                        `'. ${constants_1.VENV_BIN_ACTIVATE} && ${startScript} ${quotedArgsString}'`,
                    ],
                    cwd: '.',
                    tty,
                    expose5000: true,
                    superuser: !noSuperuser,
                    targetHardware,
                });
                break;
            }
            default: {
                throw new Error(`Unexpected target protocol "${targetProtocol}"`);
            }
        }
    }
    else {
        // There is no target json file
        if (!environment_1.ALWAYSAI_HOME && environment_1.ALWAYSAI_OS_PLATFORM !== 'darwin') {
            throw new alwayscli_1.CliTerseError(`Target configuration file not found. Did you run "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME} app deploy"?`);
        }
        if (environment_1.ALWAYSAI_OS_PLATFORM === 'win32') {
            if (!fs_1.existsSync(constants_1.VENV_SCRIPTS_ACTIVATE)) {
                throw new alwayscli_1.CliTerseError(`File not found "${constants_1.VENV_SCRIPTS_ACTIVATE}". Did you run "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME} app install"?`);
            }
            exitCode = await run_foreground_1.runForeground({
                exe: 'cmd.exe',
                args: ['/c', `${constants_1.VENV_SCRIPTS_ACTIVATE} && ${startScript} ${args.join(' ')}`],
            });
        }
        else if (environment_1.ALWAYSAI_OS_PLATFORM === 'darwin') {
            if (!fs_1.existsSync(constants_1.VENV_BIN_ACTIVATE)) {
                throw new alwayscli_1.CliTerseError(`File not found "${constants_1.VENV_BIN_ACTIVATE}". Did you run "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME} app install"?`);
            }
            exitCode = await run_foreground_1.runForeground({
                exe: '/bin/sh',
                args: [`-c`, `. ${constants_1.VENV_BIN_ACTIVATE} && ${startScript} ${quotedArgsString}`],
            });
        }
        else {
            if (!fs_1.existsSync(constants_1.VENV_BIN_ACTIVATE)) {
                throw new alwayscli_1.CliTerseError(`File not found "${constants_1.VENV_BIN_ACTIVATE}". Did you run "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME} app install"?`);
            }
            exitCode = await run_foreground_1.runForeground({
                exe: '/bin/bash',
                args: [
                    '-o',
                    'onecmd',
                    '-c',
                    `. ${constants_1.VENV_BIN_ACTIVATE} && ${startScript} ${quotedArgsString}`,
                ],
            });
        }
    }
    return exitCode || 0;
}
exports.appStartComponent = appStartComponent;
//# sourceMappingURL=app-start-component.js.map