"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ssh_spawner_1 = require("../util/spawner/ssh-spawner");
const js_spawner_1 = require("../util/spawner/js-spawner");
const echo_1 = require("../util/echo");
const alwayscli_1 = require("@alwaysai/alwayscli");
const constants_1 = require("../constants");
const spinner_1 = require("../util/spinner");
async function checkForDockerComponent(props = {}) {
    const spawner = props.targetHostname
        ? ssh_spawner_1.SshSpawner({ targetHostname: props.targetHostname })
        : js_spawner_1.JsSpawner();
    {
        const spinner = spinner_1.Spinner('Check docker executable');
        try {
            await spawner.run({ exe: 'docker', args: ['--version'] });
            spinner.succeed();
        }
        catch (ex) {
            spinner.fail('Command "docker --version" failed');
            echo_1.echo(ex.message);
            echo_1.echo(`Please install docker${props.targetHostname ? ' on your target system' : ''}, or \nverify the existing installation if there is one.`);
            echo_1.echo();
            echo_1.echo('For installation instructions for your operating system, see:');
            echo_1.echo();
            echo_1.echo('  https://docs.docker.com/install/');
            echo_1.echo();
            throw new alwayscli_1.CliTerseError('Failed to run "docker --version"');
        }
    }
    {
        const spinner = spinner_1.Spinner('Check docker permissions');
        try {
            await spawner.run({
                exe: 'docker',
                args: ['run', '--rm', constants_1.DOCKER_TEST_IMAGE_ID],
            });
            spinner.succeed();
        }
        catch (ex) {
            spinner.fail(`Command "docker run ${constants_1.DOCKER_TEST_IMAGE_ID}" failed`);
            echo_1.echo(ex.message);
            echo_1.echo('Please double-check that you\'ve complete the "Manage Docker as a non-root user" post-install steps described here:');
            echo_1.echo();
            echo_1.echo('  https://docs.docker.com/install/linux/linux-postinstall/');
            echo_1.echo();
            throw new alwayscli_1.CliTerseError(`Failed to run "docker run ${constants_1.DOCKER_TEST_IMAGE_ID}"`);
        }
    }
}
exports.checkForDockerComponent = checkForDockerComponent;
//# sourceMappingURL=check-for-docker-component.js.map