"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const child_process_1 = require("child_process");
const util_1 = require("util");
const alwayscli_1 = require("@alwaysai/alwayscli");
const constants_1 = require("../constants");
const confirm_write_file_prompt_component_1 = require("./confirm-write-file-prompt-component");
const unable_to_proceed_without_message_1 = require("../util/unable-to-proceed-without-message");
const spinner_1 = require("../util/spinner");
const mkdirp = require("mkdirp");
const path_1 = require("path");
const environment_1 = require("../environment");
const WRITE_MESSAGE = `Write ${constants_1.PRIVATE_KEY_FILE_PRETTY_PATH}`;
exports.PUBLIC_KEY_FILE_COMMENT = 'Generated by the alwaysAI CLI';
async function findOrWritePrivateKeyFileComponent(props) {
    const { yes } = props;
    if (fs_1.existsSync(constants_1.PRIVATE_KEY_FILE_PATH)) {
        // Make sure that the public part of the key is in place. It should be if it
        // was created with ssh-keygen. It might not be if the private key was
        // copied to this host from elsewhere.
        if (!fs_1.existsSync(constants_1.PUBLIC_KEY_FILE_PATH)) {
            const confirmed = yes ||
                (await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({
                    fileName: constants_1.PUBLIC_KEY_FILE_PRETTY_PATH,
                    description: 'Public key file',
                }));
            if (!confirmed) {
                throw new alwayscli_1.CliTerseError(unable_to_proceed_without_message_1.UnableToProceedWithoutMessage(constants_1.PUBLIC_KEY_FILE_PATH));
            }
            const spinner = spinner_1.Spinner(`Write ${constants_1.PUBLIC_KEY_FILE_PRETTY_PATH}`);
            try {
                const { stdout } = await util_1.promisify(child_process_1.execFile)('ssh-keygen', [
                    '-y',
                    '-f',
                    constants_1.PRIVATE_KEY_FILE_PATH,
                ]);
                await fs_1.writeFileSync(constants_1.PUBLIC_KEY_FILE_PATH, stdout, { flag: 'wx' });
                spinner.succeed();
            }
            catch (exception) {
                if (exception.code === 'EEXIST') {
                    spinner.succeed();
                    // Unlikely scenario that the file did not exist but now does
                }
                else {
                    spinner.fail();
                    throw exception;
                }
            }
        }
    }
    else {
        // !exists
        const confirmed = yes ||
            (await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({
                fileName: constants_1.PRIVATE_KEY_FILE_PRETTY_PATH,
                description: 'Private key file',
            }));
        if (!confirmed) {
            throw new alwayscli_1.CliTerseError(unable_to_proceed_without_message_1.UnableToProceedWithoutMessage(constants_1.PRIVATE_KEY_FILE_PRETTY_PATH));
        }
        // ssh-keygen does not automatically create the .ssh directory on Windows if
        // it does not already exist. On non-Windows let's just let ssh-keygen
        // create the directory so that it has proper permissions.
        if (environment_1.ALWAYSAI_OS_PLATFORM === 'win32') {
            mkdirp.sync(path_1.dirname(constants_1.PRIVATE_KEY_FILE_PATH));
        }
        // ssh-keygen creates the private key file and the corresponding .pub file
        const spinner = spinner_1.Spinner(WRITE_MESSAGE);
        try {
            await util_1.promisify(child_process_1.execFile)('ssh-keygen', [
                '-q',
                '-b',
                '2048',
                '-t',
                'rsa',
                '-N',
                '',
                '-C',
                exports.PUBLIC_KEY_FILE_COMMENT,
                '-f',
                constants_1.PRIVATE_KEY_FILE_PATH,
            ]);
            spinner.succeed();
        }
        catch (exception) {
            spinner.fail();
            throw exception;
        }
    }
}
exports.findOrWritePrivateKeyFileComponent = findOrWritePrivateKeyFileComponent;
//# sourceMappingURL=find-or-write-private-key-file-component.js.map