"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const find_or_write_private_key_file_component_1 = require("./find-or-write-private-key-file-component");
const rimraf = require("rimraf");
const constants_1 = require("../constants");
const fs_1 = require("fs");
function readKeys() {
    const priv = fs_1.readFileSync(constants_1.PRIVATE_KEY_FILE_PATH, {
        encoding: 'utf8',
    });
    const pub = fs_1.readFileSync(constants_1.PUBLIC_KEY_FILE_PATH, {
        encoding: 'utf8',
    });
    return {
        priv,
        pub,
    };
}
describe(find_or_write_private_key_file_component_1.findOrWritePrivateKeyFileComponent.name, () => {
    const yes = true;
    it('big test of all the features', async () => {
        rimraf.sync(constants_1.PRIVATE_KEY_FILE_PATH);
        rimraf.sync(constants_1.PUBLIC_KEY_FILE_PATH);
        // Writes the private key file if it does not exist
        await find_or_write_private_key_file_component_1.findOrWritePrivateKeyFileComponent({ yes });
        const keys0 = readKeys();
        expect(keys0.priv).toMatch('PRIVATE KEY');
        expect(keys0.pub).toMatch(find_or_write_private_key_file_component_1.PUBLIC_KEY_FILE_COMMENT);
        // Regenerates public key file if it does not exist but private does
        rimraf.sync(constants_1.PUBLIC_KEY_FILE_PATH);
        await find_or_write_private_key_file_component_1.findOrWritePrivateKeyFileComponent({ yes });
        const keys1 = readKeys();
        expect(keys0.pub).toMatch(keys1.pub.trim());
        // ^^ Comment is not retained in the regenerated public key
        // Make sure the pub key gets recreated we remove the private but not the public
        rimraf.sync(constants_1.PRIVATE_KEY_FILE_PATH);
        await find_or_write_private_key_file_component_1.findOrWritePrivateKeyFileComponent({ yes });
        const keys2 = readKeys();
        expect(keys0.pub).not.toMatch(keys2.pub.trim());
    });
});
//# sourceMappingURL=find-or-write-private-key-file-component.test.js.map