"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const prompt_for_input_1 = require("../util/prompt-for-input");
const connect_by_ssh_component_1 = require("./connect-by-ssh-component");
const run_1 = require("../util/spawner-base/run");
const echo_1 = require("../util/echo");
const set_up_passwordless_ssh_component_1 = require("./set-up-passwordless-ssh-component");
async function targetHostnamePromptComponent(props) {
    let targetHostname = props.targetHostname || '';
    let connected = false;
    while (!connected) {
        targetHostname = await promptForTargetHostname();
        try {
            await connect_by_ssh_component_1.connectBySshComponent({
                targetHostname,
                warnOrFail: 'warn',
            });
            connected = true;
        }
        catch (exception) {
            if (exception &&
                exception.code === alwayscli_1.CLI_TERSE_ERROR &&
                typeof exception.message === 'string' &&
                (exception.message.includes(run_1.PROCESS_EXITED_WITH_NON_ZERO_STATUS_CODE) ||
                    exception.message.includes(connect_by_ssh_component_1.TIMED_OUT_CONNECTING_TO))) {
                if (exception.message.includes('Permission denied')) {
                    await set_up_passwordless_ssh_component_1.setUpPasswordlessSshComponent({ targetHostname });
                    connected = true;
                }
                else {
                    echo_1.echo(exception.message);
                    echo_1.echo('Cannot connect to your device. Please check the address and try again.');
                }
            }
            else {
                throw exception;
            }
        }
    }
    return targetHostname;
    async function promptForTargetHostname() {
        const answers = await prompt_for_input_1.promptForInput({
            purpose: 'for the target hostname',
            questions: [
                {
                    type: 'text',
                    name: 'hostname',
                    message: 'Please enter the hostname (with optional user name) to connect to your device via ssh (e.g. "pi@1.2.3.4"):',
                    initial: targetHostname,
                    validate: value => (!value ? 'Value is required' : true),
                },
            ],
        });
        return answers.hostname;
    }
}
exports.targetHostnamePromptComponent = targetHostnamePromptComponent;
//# sourceMappingURL=target-hostname-prompt-component.js.map