"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const target_protocol_prompt_component_1 = require("./target-protocol-prompt-component");
const check_for_docker_component_1 = require("./check-for-docker-component");
const target_json_file_1 = require("../util/target-json-file");
const target_hostname_prompt_component_1 = require("./target-hostname-prompt-component");
const target_path_prompt_component_1 = require("./target-path-prompt-component");
const constants_1 = require("../constants");
const write_target_json_file_component_1 = require("./write-target-json-file-component");
const find_or_write_private_key_file_component_1 = require("./find-or-write-private-key-file-component");
const find_or_write_dockerfile_component_1 = require("./find-or-write-dockerfile-component");
const child_spawner_1 = require("../util/spawner/child-spawner");
const ssh_spawner_1 = require("../util/spawner/ssh-spawner");
async function targetJsonPromptComponent(props = {}) {
    const yes = false;
    const currentTargetJson = target_json_file_1.TargetJsonFile().readIfExists();
    const targetProtocol = await target_protocol_prompt_component_1.targetProtocolPromptComponent({
        targetProtocol: props.targetProtocol || (currentTargetJson && currentTargetJson.targetProtocol),
    });
    let targetHardware = 'generic';
    switch (targetProtocol) {
        case 'docker:':
            await check_for_docker_component_1.checkForDockerComponent();
            await find_or_write_dockerfile_component_1.findOrWriteDockerfileComponent({ yes });
            const localUname = await child_spawner_1.ChildSpawner({ path: '.' }).run({
                exe: 'uname',
                args: ['-r'],
            });
            if (localUname.includes('tegra')) {
                targetHardware = 'nvidia';
            }
            write_target_json_file_component_1.writeTargetJsonFileComponent({
                targetProtocol,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
            });
            break;
        case 'ssh+docker:':
            await find_or_write_dockerfile_component_1.findOrWriteDockerfileComponent({ yes });
            await find_or_write_private_key_file_component_1.findOrWritePrivateKeyFileComponent({ yes });
            let currentTargetHostname;
            let currentTargetPath;
            if (currentTargetJson && currentTargetJson.targetProtocol === 'ssh+docker:') {
                currentTargetHostname = currentTargetJson.targetHostname;
                currentTargetPath = currentTargetJson.targetPath;
            }
            const targetHostname = await target_hostname_prompt_component_1.targetHostnamePromptComponent({
                targetHostname: props.targetHostname || currentTargetHostname,
            });
            await check_for_docker_component_1.checkForDockerComponent({ targetHostname });
            const targetPath = await target_path_prompt_component_1.targetPathPromptComponent({
                targetHostname,
                targetPath: props.targetPath || currentTargetPath,
            });
            const externalUname = await ssh_spawner_1.SshSpawner({ targetHostname }).run({
                exe: 'uname',
                args: ['-r'],
            });
            if (externalUname.includes('tegra')) {
                targetHardware = 'nvidia';
            }
            await write_target_json_file_component_1.writeTargetJsonFileComponent({
                targetProtocol,
                targetHostname,
                targetPath,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
            });
            break;
        default:
            throw new Error(`Unexpected target protocol ${targetProtocol}`);
    }
}
exports.targetJsonPromptComponent = targetJsonPromptComponent;
//# sourceMappingURL=target-json-prompt-component.js.map