"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const prompt_for_input_1 = require("../util/prompt-for-input");
const create_target_directory_component_1 = require("./create-target-directory-component");
const echo_1 = require("../util/echo");
const target_path_default_value_1 = require("../util/target-path-default-value");
const confirm_prompt_component_1 = require("./confirm-prompt-component");
async function targetPathPromptComponent(props) {
    let writable = false;
    let targetPath;
    let skipPromptForTargetPath;
    const targetPathDefaultValue = target_path_default_value_1.TargetPathDefaultValue();
    if (props.targetPath) {
        // Existing value or command-line input
        targetPath = props.targetPath;
        skipPromptForTargetPath = false;
    }
    else {
        targetPath = targetPathDefaultValue;
        skipPromptForTargetPath = await confirm_prompt_component_1.confirmPromptComponent({
            message: `Would you like to use the default installation directory "${targetPathDefaultValue}"?`,
        });
    }
    while (!writable) {
        if (!skipPromptForTargetPath) {
            ({ targetPath } = await prompt_for_input_1.promptForInput({
                purpose: 'for a target path',
                questions: [
                    {
                        type: 'text',
                        name: 'targetPath',
                        message: 'Where do you want to run the app? Enter a filesystem path:',
                        initial: targetPath || targetPathDefaultValue,
                        validate: value => (!value ? 'Value is required' : true),
                    },
                ],
            }));
        }
        try {
            await create_target_directory_component_1.createTargetDirectoryComponent({
                targetHostname: props.targetHostname,
                targetPath,
            });
            writable = true;
        }
        catch (exception) {
            if (exception.code === alwayscli_1.CLI_TERSE_ERROR) {
                skipPromptForTargetPath = false;
                echo_1.echo(exception.message);
            }
            else {
                throw exception;
            }
        }
    }
    return targetPath;
}
exports.targetPathPromptComponent = targetPathPromptComponent;
//# sourceMappingURL=target-path-prompt-component.js.map