"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rimraf = require("rimraf");
const constants_1 = require("../constants");
const echo_1 = require("../util/echo");
const app_start_component_1 = require("./app-start-component");
const aai_1 = require("../util/aai");
const target_protocol_1 = require("../util/target-protocol");
const ssh_spawner_1 = require("../util/spawner/ssh-spawner");
const run_with_echo_and_proceed_prompt_1 = require("../util/run-with-echo-and-proceed-prompt");
const target_json_file_1 = require("../util/target-json-file");
const target_path_default_value_1 = require("../util/target-path-default-value");
const environment_1 = require("../environment");
async function testAppComponent(props) {
    const { yes, targetHostname, reset } = props;
    const targetProtocol = targetHostname
        ? target_protocol_1.TargetProtocol['ssh+docker:']
        : environment_1.ALWAYSAI_HOME
            ? undefined
            : target_protocol_1.TargetProtocol['docker:'];
    const targetPath = target_path_default_value_1.TargetPathDefaultValue();
    const targetJsonFile = target_json_file_1.TargetJsonFile();
    if (reset) {
        if (targetJsonFile.exists()) {
            echo_1.echoCommandInvocation(`rm -f ${constants_1.TARGET_JSON_FILE_NAME}`);
            targetJsonFile.remove();
        }
    }
    const appConfigureCommandParts = ['app configure'];
    if (yes) {
        appConfigureCommandParts.push('--yes');
    }
    if (targetProtocol) {
        appConfigureCommandParts.push('--protocol', targetProtocol);
    }
    if (targetHostname) {
        appConfigureCommandParts.push('--hostname', targetHostname);
    }
    await aai_1.aai(appConfigureCommandParts.join(' '), { yes });
    if (reset) {
        if (targetHostname) {
            echo_1.echoCommandInvocation(`ssh ${targetHostname} rm -rf ${targetPath}`);
            const targetHostSpawner = ssh_spawner_1.SshSpawner({ targetHostname });
            await targetHostSpawner.rimraf(targetPath);
        }
        else {
            echo_1.echoCommandInvocation('rm -rf models');
            rimraf.sync('models');
            echo_1.echoCommandInvocation(`rm -rf ${constants_1.VENV}`);
            rimraf.sync(constants_1.VENV);
        }
    }
    if (targetJsonFile.exists()) {
        await aai_1.aai('app deploy', { yes });
    }
    else {
        await aai_1.aai('app install', { yes });
    }
    await run_with_echo_and_proceed_prompt_1.runWithEchoAndProceedPrompt(app_start_component_1.appStartComponent, [], {
        yes,
        functionName: 'aai app start',
    });
}
exports.testAppComponent = testAppComponent;
//# sourceMappingURL=test-app-component.js.map