"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mkdirp = require("mkdirp");
const rimraf = require("rimraf");
const fs_1 = require("fs");
const constants_1 = require("../constants");
const echo_1 = require("../util/echo");
const model_package_cache_1 = require("../util/model-package-cache");
const aai_1 = require("../util/aai");
const test_app_component_1 = require("./test-app-component");
const cd_1 = require("../util/cd");
const system_id_1 = require("../util/system-id");
const SCRATCH_APP = 'scratch-app';
const PYTHON_APPLICATION_CODE = `
import http.server
import socketserver

PORT = 5000

httpd = socketserver.TCPServer(("", PORT), http.server.SimpleHTTPRequestHandler)
print("Listening http://0.0.0.0:{}/".format(PORT))
httpd.serve_forever()
`;
async function testScratchAppComponent(props) {
    const { yes, reset, targetHostname } = props;
    if (reset) {
        echo_1.echoCommandInvocation(`rm -rf ${SCRATCH_APP}`);
        rimraf.sync(SCRATCH_APP);
        echo_1.echoCommandInvocation(`rm -rf ${constants_1.MODEL_PACKAGE_CACHE_DIR}/${system_id_1.getSystemId()}`);
        await model_package_cache_1.modelPackageCache.clear();
    }
    if (!fs_1.existsSync(SCRATCH_APP)) {
        mkdirp.sync(SCRATCH_APP);
    }
    cd_1.cd(SCRATCH_APP);
    await test_app_component_1.testAppComponent({ targetHostname, reset, yes });
    fs_1.writeFileSync(constants_1.APP_PY_FILE_NAME, PYTHON_APPLICATION_CODE);
    await aai_1.aai('app models add alwaysai/squeezenet_v1.1 alwaysai/mobilenet_v1_1.0_224', {
        yes,
    });
    await aai_1.aai('app show', { yes });
    // TODO: Uncomment this once the requirements.txt feature works
    // echoCommandInvocation(`echo "bleach==2.0.0" > ${PYTHON_REQUIREMENTS_FILE_NAME}`);
    // writeFileSync(PYTHON_REQUIREMENTS_FILE_NAME, 'bleach==2.0.0\n');
    await test_app_component_1.testAppComponent({ targetHostname, reset: false, yes: true });
    cd_1.cd('..');
}
exports.testScratchAppComponent = testScratchAppComponent;
//# sourceMappingURL=test-scratch-app-component.js.map