"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const t = require("io-ts");
const constants_1 = require("../constants");
const fs_1 = require("fs");
const echo_1 = require("../util/echo");
const rimraf = require("rimraf");
const config_nodejs_1 = require("@alwaysai/config-nodejs");
const model_package_cache_1 = require("../util/model-package-cache");
const aai_1 = require("../util/aai");
const test_app_component_1 = require("./test-app-component");
const cd_1 = require("../util/cd");
const system_id_1 = require("../util/system-id");
const TESTED_STARTER_APPS_JSON_FILE_NAME = 'alwaysai.tested-starter-apps.json';
async function underscoreTestStarterAppsComponent(props) {
    const { yes, targetHostname, reset } = props;
    const jsonFile = config_nodejs_1.ConfigFile({
        path: TESTED_STARTER_APPS_JSON_FILE_NAME,
        codec: t.record(t.string, t.boolean),
        initialValue: {},
    });
    if (reset) {
        echo_1.echoCommandInvocation(`rm -rf ${constants_1.PRIVATE_KEY_FILE_PRETTY_PATH}`);
        rimraf.sync(constants_1.PRIVATE_KEY_FILE_PATH);
        echo_1.echoCommandInvocation(`rm -rf ${TESTED_STARTER_APPS_JSON_FILE_NAME}`);
        jsonFile.remove();
        echo_1.echoCommandInvocation(`rm -rf ${constants_1.ALWAYSAI_STARTER_APPS}`);
        rimraf.sync(constants_1.ALWAYSAI_STARTER_APPS);
        echo_1.echoCommandInvocation(`rm -rf ${constants_1.MODEL_PACKAGE_CACHE_DIR}/${system_id_1.getSystemId()}`);
        await model_package_cache_1.modelPackageCache.clear();
    }
    if (!fs_1.existsSync(constants_1.ALWAYSAI_STARTER_APPS)) {
        await aai_1.aai('get-starter-apps', { yes });
    }
    jsonFile.initialize();
    cd_1.cd(constants_1.ALWAYSAI_STARTER_APPS);
    for (const fileName of fs_1.readdirSync('.')) {
        cd_1.cd(fileName);
        const tested = jsonFile.read()[fileName];
        if (!tested) {
            await test_app_component_1.testAppComponent({ yes, targetHostname, reset });
            jsonFile.update(testedJson => {
                testedJson[fileName] = true;
            });
        }
        cd_1.cd('..');
    }
    cd_1.cd('..');
}
exports.underscoreTestStarterAppsComponent = underscoreTestStarterAppsComponent;
//# sourceMappingURL=test-starter-apps-component.js.map