"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const logSymbols = require("log-symbols");
const audit_1 = require("./util/audit");
const environment_1 = require("./environment");
const post_tracking_data_to_segment_1 = require("./util/post-tracking-data-to-segment");
exports.enhancer = argvInterface => async (...argv) => {
    if (environment_1.ALWAYSAI_AUDIT_LOG) {
        try {
            await audit_1.openAuditLog(environment_1.ALWAYSAI_AUDIT_LOG);
        }
        catch (exception) {
            console.error(`${logSymbols.warning} Failed to open audit log: "${exception.message}"`);
        }
    }
    audit_1.audit(`start "${argv.join(' ')}"`);
    const argvString = argv.join(' ');
    const trackingPromise = post_tracking_data_to_segment_1.postTrackingDataToSegment(argvString);
    try {
        const returnValue = await argvInterface(...argv);
        await new Promise(resolve => {
            audit_1.audit(`end "${returnValue}"`, () => {
                resolve();
            });
        });
        await trackingPromise;
        return returnValue;
    }
    catch (exception) {
        if (exception.code !== alwayscli_1.CLI_USAGE_ERROR) {
            await Promise.all([
                post_tracking_data_to_segment_1.postTrackingDataToSegment(argvString, exception),
                trackingPromise,
            ]);
        }
        else {
            await trackingPromise;
        }
        throw exception;
    }
};
//# sourceMappingURL=enhancer.js.map