"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const target_json_file_1 = require("../../util/target-json-file");
exports.appExecCliLeaf = alwayscli_1.CliLeaf({
    name: 'exec',
    description: 'Run a command in the target directory',
    namedInputs: {
        superuser: alwayscli_1.CliFlagInput({ description: 'Run the command as superuser "root"' }),
        'no-container': alwayscli_1.CliFlagInput({
            description: 'Run the command directly on the target host, not in a container',
        }),
    },
    positionalInput: alwayscli_1.CliStringArrayInput({
        placeholder: '<command> [<args>]',
        required: true,
    }),
    async action([exe, ...args], opts) {
        const targetJsonFile = target_json_file_1.TargetJsonFile();
        if (opts['no-container']) {
            if (opts.superuser) {
                throw new alwayscli_1.CliTerseError('--superuser is not yet supported with --no-container');
            }
            targetJsonFile.readHostSpawner().runForegroundSync({ exe, args, cwd: '.' });
        }
        else {
            targetJsonFile
                .readContainerSpawner()
                .runForegroundSync({ exe, args, cwd: '.', superuser: opts.superuser });
        }
    },
});
//# sourceMappingURL=exec.js.map