"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const target_json_file_1 = require("../../util/target-json-file");
const constants_1 = require("../../constants");
exports.appShellCliLeaf = alwayscli_1.CliLeaf({
    name: 'shell',
    description: 'Launch a bash shell in the target directory',
    namedInputs: {
        'no-container': alwayscli_1.CliFlagInput({
            description: 'Open the shell on the target host, not in a container on the target host',
        }),
        superuser: alwayscli_1.CliFlagInput({
            description: 'Open the shell as superuser "root"',
        }),
    },
    async action(_, opts) {
        const targetJsonFile = target_json_file_1.TargetJsonFile();
        const targetJson = targetJsonFile.read();
        const tty = process.stdin.isTTY;
        switch (targetJson.targetProtocol) {
            case 'docker:': {
                targetJsonFile.readContainerSpawner().runForegroundSync({
                    exe: '/bin/bash',
                    args: ['--rcfile', constants_1.VENV_BIN_ACTIVATE],
                    tty,
                    cwd: '.',
                    expose5000: true,
                    superuser: opts.superuser,
                });
                break;
            }
            case 'ssh+docker:': {
                if (opts['no-container']) {
                    if (opts.superuser) {
                        throw new alwayscli_1.CliTerseError('--superuser is not yet supported with --no-container');
                    }
                    targetJsonFile.readHostSpawner().runForegroundSync({
                        exe: '/bin/bash',
                        tty,
                        cwd: '.',
                        expose5000: true,
                    });
                }
                else {
                    targetJsonFile.readContainerSpawner().runForegroundSync({
                        exe: '/bin/bash',
                        args: ['--rcfile', constants_1.VENV_BIN_ACTIVATE],
                        tty,
                        cwd: '.',
                        expose5000: true,
                        superuser: opts.superuser,
                    });
                }
                break;
            }
            default: {
                throw new Error('Unsupported protocol');
            }
        }
    },
});
//# sourceMappingURL=shell.js.map