"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const fs = require('fs');
const path = require('path');
const rimraf = require('rimraf');
const AdmZip = require('adm-zip');
const parseStringSync = require('xml2js-parser').parseStringSync;
const xml2js = require('xml2js');
let maxIndex = 0; // Only mutated in function moveData
const incrementFileName = function (annotationJson, maxIndex_) {
    const fileNameField = annotationJson.annotation.filename[0];
    const fileNameFieldIndex = parseInt(fileNameField.split('.')[0], 0);
    const newFileNameIndex = fileNameFieldIndex + maxIndex_;
    const newFileName = `${newFileNameIndex}.jpg`;
    annotationJson.annotation.filename[0] = newFileName;
    return newFileName;
};
const loadAnnotationFile = function (annotationPath) {
    return parseStringSync(fs.readFileSync(annotationPath));
};
const moveData = function (tempDir, outputImagesDir, outputAnnotationDir) {
    const tempAnnotationDir = path.join(tempDir, 'Annotations');
    const annotationFilesNames = fs.readdirSync(tempAnnotationDir);
    const dirFileNameIndexArray = [];
    annotationFilesNames.forEach((annotationFileName) => {
        // Increment FileName Field in Annotation File
        const annotationJson_ = loadAnnotationFile(path.join(tempAnnotationDir, annotationFileName));
        if (annotationJson_.annotation.filename == null) {
            throw 'filename field not found in ${annotationFileName}';
        }
        const originalImageFileName = JSON.parse(JSON.stringify(annotationJson_.annotation.filename[0])); // Deep copy
        const newImageFileName = incrementFileName(annotationJson_, maxIndex);
        // Move associated image file to new location
        fs.renameSync(path.join(tempDir, 'JPEGImages', originalImageFileName), path.join(outputImagesDir, newImageFileName));
        // Write modified annotationFile to location with new index, add index to index array
        const originalFilenameIndex = parseInt(annotationFileName.split('.')[0], undefined);
        dirFileNameIndexArray.push(originalFilenameIndex);
        const newFileNameIndex = originalFilenameIndex + maxIndex;
        const newAnnotationFilePath = path.join(outputAnnotationDir, `${newFileNameIndex}.xml`);
        const builder = new xml2js.Builder({
            headless: true,
        });
        const modifiedAnnotationXml = builder.buildObject(annotationJson_);
        fs.writeFileSync(newAnnotationFilePath, modifiedAnnotationXml);
    });
    // Update maxIndex with maximum index in this dataset
    maxIndex = Math.max.apply(Math, dirFileNameIndexArray) + maxIndex;
    // Clean up temp dir
    rimraf.sync(path.join(tempDir, '*'));
};
exports.datasetMerge = alwayscli_1.CliLeaf({
    name: 'merge',
    description: 'Merge 2 datasets',
    positionalInput: alwayscli_1.CliStringArrayInput({
        placeholder: '</path/to/dataset1.zip> </path/to/dataset2.zip> ...',
        required: true,
    }),
    namedInputs: {
        'output-dir': alwayscli_1.CliStringInput({
            description: 'Path of the output zip file.',
        }),
    },
    async action([...args], opts) {
        const tempOutputDir = 'temp-merged-dataset';
        const outputAnnotationDir = path.join(tempOutputDir, 'Annotations');
        const outputImagesDir = path.join(tempOutputDir, 'JPEGImages');
        fs.mkdirSync(tempOutputDir, { recursive: true });
        fs.mkdirSync(outputAnnotationDir);
        fs.mkdirSync(outputImagesDir);
        const tempDir = 'temp-dataset';
        args.forEach(dataSet => {
            const zip = new AdmZip(dataSet);
            zip.extractAllTo(tempDir, true);
            console.log('------------------------------------------');
            console.log('Merging dataset ', dataSet);
            moveData(tempDir, outputImagesDir, outputAnnotationDir);
        });
        const outputZip = opts['output-dir'] || 'merged-dataset.zip';
        const zip = new AdmZip();
        zip.addLocalFolder(tempOutputDir);
        zip.writeZip(outputZip);
        rimraf.sync(path.join(tempOutputDir));
        rimraf.sync(path.join(tempDir));
    },
});
//# sourceMappingURL=merge.js.map