"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const check_user_is_logged_in_component_1 = require("../components/check-user-is-logged-in-component");
const yes_cli_input_1 = require("../cli-inputs/yes-cli-input");
const rpc_client_1 = require("../util/rpc-client");
const model_package_cache_1 = require("../util/model-package-cache");
const download_model_package_to_cache_1 = require("../util/download-model-package-to-cache");
const fs_1 = require("fs");
const model_id_1 = require("../util/model-id");
const run_with_spinner_1 = require("../util/run-with-spinner");
const pump = require("pump");
const environment_1 = require("../environment");
exports.getModelPackageCliLeaf = alwayscli_1.CliLeaf({
    name: 'get-model-package',
    description: 'Get a model package',
    hidden: !environment_1.ALWAYSAI_SHOW_HIDDEN,
    namedInputs: {
        id: alwayscli_1.CliStringInput({
            description: 'An alwaysAI model ID, e.g. alwaysai/mobilenet_ssd',
            required: true,
        }),
        version: alwayscli_1.CliNumberInput({
            description: 'The version number of the model',
        }),
        yes: yes_cli_input_1.yesCliInput,
    },
    async action(_, { yes, id, version: maybeVersion }) {
        const { publisher, name } = model_id_1.ModelId.parse(id);
        await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes });
        const version = maybeVersion || (await rpc_client_1.CliRpcClient().getModelVersion({ id })).version;
        const fileName = `${publisher}-${name}-${version}.tar.gz`;
        await run_with_spinner_1.runWithSpinner(async () => {
            if (!model_package_cache_1.modelPackageCache.has(id, version)) {
                await download_model_package_to_cache_1.downloadModelPackageToCache(id, version);
            }
            await new Promise((resolve, reject) => {
                pump(model_package_cache_1.modelPackageCache.read(id, version), fs_1.createWriteStream(fileName), err => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve();
                    }
                });
            });
        }, [], `Getting ${fileName}`);
    },
});
//# sourceMappingURL=get-model-package.js.map