"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const cloud_api_1 = require("@alwaysai/cloud-api");
const rpc_client_1 = require("../util/rpc-client");
const environment_1 = require("../environment");
const rpcMethodCliLeaves = Object.entries(cloud_api_1.rpcMethodSpecs).map(([methodName, { description }]) => {
    return alwayscli_1.CliLeaf({
        name: methodName,
        description,
        positionalInput: alwayscli_1.CliJsonInput({
            placeholder: '<args>',
            description: 'Method arguments array as a JSON string',
        }),
        async action(args) {
            const method = rpc_client_1.CliRpcClient()[methodName];
            const result = await method(...(args || []));
            return result;
        },
    });
});
const rpcRawCliLeaf = alwayscli_1.CliLeaf({
    name: 'raw',
    positionalInput: alwayscli_1.CliJsonInput({
        required: true,
    }),
    description: 'Send a custom data payload to the RPC endpoint',
    async action(data) {
        return await rpc_client_1.CliRpcClient().raw(data);
    },
});
exports.rpc = alwayscli_1.CliBranch({
    name: 'rpc',
    hidden: !environment_1.ALWAYSAI_SHOW_HIDDEN,
    description: 'Call the alwaysAI Cloud API RPC interface',
    subcommands: [...rpcMethodCliLeaves, rpcRawCliLeaf],
});
//# sourceMappingURL=rpc.js.map