"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const alwayscli_1 = require("@alwaysai/alwayscli");
const alwaysai_user_email_cli_input_1 = require("../../cli-inputs/alwaysai-user-email-cli-input");
const alwaysai_user_password_cli_input_1 = require("../../cli-inputs/alwaysai-user-password-cli-input");
const yes_cli_input_1 = require("../../cli-inputs/yes-cli-input");
const alwaysai_user_login_prompt_component_1 = require("../../components/alwaysai-user-login-prompt-component");
const required_with_yes_message_1 = require("../../util/required-with-yes-message");
const alwaysai_user_login_yes_component_1 = require("../../components/alwaysai-user-login-yes-component");
const echo_1 = require("../../util/echo");
const authentication_client_1 = require("../../util/authentication-client");
exports.userLogin = alwayscli_1.CliLeaf({
    name: 'login',
    description: 'Log in to the alwaysAI Cloud',
    namedInputs: {
        yes: yes_cli_input_1.yesCliInput,
        email: alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput,
        password: alwaysai_user_password_cli_input_1.alwaysaiUserPasswordCliInput,
    },
    async action(_, { yes, email, password }) {
        if (yes) {
            if (!email || !password) {
                throw new alwayscli_1.CliUsageError(required_with_yes_message_1.RequiredWithYesMessage('email', 'password'));
            }
            await alwaysai_user_login_yes_component_1.alwaysaiUserLoginYesComponent({
                alwaysaiUserEmail: email,
                alwaysaiUserPassword: password,
            });
        }
        else {
            const authenticationClient = authentication_client_1.CliAuthenticationClient();
            if (authenticationClient.isSignedIn()) {
                const { email } = await authenticationClient.getInfo();
                echo_1.echo(`Already logged in as ${chalk_1.default.bold(email)}`);
            }
            else {
                await alwaysai_user_login_prompt_component_1.alwaysaiUserLoginPromptComponent({
                    alwaysaiUserEmail: email,
                    alwaysaiUserPassword: password,
                });
            }
        }
    },
});
//# sourceMappingURL=login.js.map