"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const t = require("io-ts");
const config_nodejs_1 = require("@alwaysai/config-nodejs");
const credentialsJsonCodec = t.record(t.string, t.any);
exports.credentialsJsonFile = CredentialsJsonFile(config_nodejs_1.ALWAYSAI_CONFIG_DIR);
function CredentialsJsonFile(dir) {
    const path = path_1.join(dir, 'alwaysai.credentials.json');
    const configFile = config_nodejs_1.ConfigFile({
        path,
        codec: credentialsJsonCodec,
        initialValue: {},
    });
    configFile.initialize();
    const authenticationStorage = {
        setItem(key, value) {
            configFile.update(config => {
                config[key] = value;
            });
        },
        getItem(key) {
            return configFile.read()[key] || '';
        },
        removeItem(key) {
            configFile.update(config => {
                delete config[key];
            });
        },
        clear() {
            configFile.write({});
        },
    };
    return authenticationStorage;
}
exports.CredentialsJsonFile = CredentialsJsonFile;
//# sourceMappingURL=credentials-json-file.js.map