"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
const cloud_api_1 = require("@alwaysai/cloud-api");
const authentication_client_1 = require("./authentication-client");
const alwayscli_1 = require("@alwaysai/alwayscli");
const pump = require("pump");
const fs_1 = require("fs");
const tar = require("tar");
const path_1 = require("path");
const rimraf = require("rimraf");
const mkdirp = require("mkdirp");
const system_id_1 = require("./system-id");
const constants_1 = require("../constants");
async function getStarterApps(dir = process.cwd()) {
    const systemDomainName = cloud_api_1.SystemDomainName(system_id_1.getSystemId());
    const starterAppsUrl = `https://dashboard.${systemDomainName}/docs/${constants_1.ALWAYSAI_STARTER_APPS}.tar.gz`;
    const destinationDir = path_1.join(dir, constants_1.ALWAYSAI_STARTER_APPS);
    if (fs_1.existsSync(destinationDir)) {
        throw new alwayscli_1.CliTerseError(`Directory "${destinationDir}" already exists`);
    }
    const tmpDir = `${destinationDir}.download`;
    rimraf.sync(tmpDir);
    const authorizationHeader = await authentication_client_1.CliAuthenticationClient().getAuthorizationHeader();
    const jwt = authorizationHeader.Authorization.split(' ')[1];
    const cookieHeader = {
        cookie: `token=${jwt}`,
    };
    mkdirp.sync(tmpDir);
    try {
        const response = await node_fetch_1.default(starterAppsUrl, {
            redirect: 'manual',
            headers: Object.assign({}, cookieHeader),
        });
        if (!response.ok) {
            throw new alwayscli_1.CliTerseError(`Server responded ${response.status} "${response.statusText}"`);
        }
        await new Promise((resolve, reject) => {
            pump([response.body, tar.extract({ cwd: tmpDir })], err => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
        const fileNames = fs_1.readdirSync(tmpDir);
        if (fileNames.length !== 1 || !fileNames[0]) {
            throw new Error(`Expected ${constants_1.ALWAYSAI_STARTER_APPS} package to contain a single directory. ${constants_1.PLEASE_REPORT_THIS_ERROR_MESSAGE}`);
        }
        await fs_1.renameSync(path_1.join(tmpDir, fileNames[0]), destinationDir);
    }
    finally {
        rimraf.sync(tmpDir);
    }
}
exports.getStarterApps = getStarterApps;
//# sourceMappingURL=get-starter-apps.js.map