"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const util_1 = require("util");
const mkdirp = require("mkdirp");
const pump = require("pump");
const rimraf = require("rimraf");
const constants_1 = require("../constants");
const random_string_1 = require("./random-string");
const model_id_1 = require("./model-id");
const system_id_1 = require("./system-id");
exports.modelPackageCache = {
    has(id, version) {
        const modelPackagePath = ModelPackagePath(id, version);
        return fs_1.existsSync(modelPackagePath);
    },
    read(id, version) {
        const modelPackagePath = ModelPackagePath(id, version);
        return fs_1.createReadStream(modelPackagePath);
    },
    async clear() {
        await new Promise((resolve, reject) => {
            rimraf(ModelPackageDirectory(), err => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
    },
    async write(id, version, readable) {
        const modelPackagePath = ModelPackagePath(id, version);
        await util_1.promisify(mkdirp)(path_1.dirname(modelPackagePath));
        const tmpFilePath = `${modelPackagePath}.${random_string_1.RandomString()}.tmp`;
        try {
            await new Promise((resolve, reject) => {
                const writeable = fs_1.createWriteStream(tmpFilePath);
                pump(readable, writeable, err => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve();
                    }
                });
            });
            await util_1.promisify(fs_1.rename)(tmpFilePath, modelPackagePath);
        }
        catch (exception) {
            try {
                await util_1.promisify(rimraf)(tmpFilePath);
            }
            finally {
                throw exception;
            }
        }
    },
    async remove(id, version) {
        const modelPackagePath = ModelPackagePath(id, version);
        await new Promise((resolve, reject) => {
            rimraf(modelPackagePath, err => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
    },
};
function ModelPackageDirectory() {
    return path_1.join(constants_1.MODEL_PACKAGE_CACHE_DIR, system_id_1.getSystemId());
}
function ModelPackagePath(id, version) {
    const { publisher, name } = model_id_1.ModelId.parse(id);
    return path_1.join(ModelPackageDirectory(), publisher, name, `${version}.tar.gz`);
}
//# sourceMappingURL=model-package-cache.js.map