"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tempy = require("tempy");
const run_and_catch_1 = require("@carnesen/run-and-catch");
const alwayscli_1 = require("@alwaysai/alwayscli");
const pump = require("pump");
const fs_1 = require("fs");
const tar = require("tar");
const model_package_cloud_client_1 = require("./model-package-cloud-client");
const model_json_file_1 = require("./model-json-file");
const path_1 = require("path");
const mock_model_1 = require("./mock-model");
describe('model package cloud client', () => {
    it(`throws ${alwayscli_1.CLI_TERSE_ERROR} error if directory does not have a model json file`, async () => {
        const tmpDir = tempy.directory();
        const exception = await run_and_catch_1.runAndCatch(model_package_cloud_client_1.modelPackageCloudClient.publish, tmpDir);
        expect(exception.code).toBe(alwayscli_1.CLI_TERSE_ERROR);
    });
    it(`publish and download`, async () => {
        const mockModel = await mock_model_1.MockModel();
        expect(mockModel.metadata.description).toBe(mockModel.json.description);
        expect(mockModel.metadata.final).toBe(true);
        expect(mockModel.metadata.failed).toBe(false);
        const modelPackageFilePath = tempy.file();
        const readable = await model_package_cloud_client_1.modelPackageCloudClient.download(mockModel.metadata.id, mockModel.metadata.version);
        await new Promise((resolve, reject) => {
            pump(readable, fs_1.createWriteStream(modelPackageFilePath), err => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
        const targetDir = tempy.directory();
        // tar automatically detects gzip compression
        await tar.extract({
            file: modelPackageFilePath,
            cwd: targetDir,
            strict: true,
        });
        const downloadedModelJsonFile = model_json_file_1.ModelJsonFile(path_1.join(targetDir, path_1.basename(mockModel.dir)));
        expect(downloadedModelJsonFile.read().description).toBe(mockModel.json.description);
    }, 100000);
});
//# sourceMappingURL=model-package-cloud-client.test.js.map