"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const echo_1 = require("./echo");
const confirm_prompt_component_1 = require("../components/confirm-prompt-component");
const chalk_1 = require("chalk");
const logSymbols = require("log-symbols");
async function runWithEchoAndProceedPrompt(func, args, props = {}) {
    const { yes = false, functionName } = props;
    const commandString = `${functionName || func.name} ${args.join(' ')}`;
    echo_1.echoCommandInvocation(commandString);
    const result = await func(...args);
    let endOfCommandMessage = `End of "${commandString}"`;
    if (typeof result !== 'undefined') {
        endOfCommandMessage = `${endOfCommandMessage} (result=${result})`;
    }
    if (!yes) {
        const confirmed = await confirm_prompt_component_1.confirmPromptComponent({
            message: `${endOfCommandMessage}. Proceed?`,
        });
        if (!confirmed) {
            throw new alwayscli_1.CliTerseError('User elected not to proceed');
        }
    }
    else {
        echo_1.echo(`${logSymbols.success} ${chalk_1.default.bold(endOfCommandMessage)}`);
    }
    echo_1.echo();
}
exports.runWithEchoAndProceedPrompt = runWithEchoAndProceedPrompt;
//# sourceMappingURL=run-with-echo-and-proceed-prompt.js.map