"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const spawner_base_1 = require("../spawner-base");
const gnu_spawner_1 = require("./gnu-spawner");
const resolve_posix_path_1 = require("../resolve-posix-path");
const alwayscli_1 = require("@alwaysai/alwayscli");
const constants_1 = require("../../constants");
const environment_1 = require("../../environment");
exports.APP_DIR = '/app';
function DockerSpawner(opts) {
    const { dockerImageId } = opts;
    if (!dockerImageId) {
        throw new alwayscli_1.CliTerseError(constants_1.EMPTY_DOCKER_IMAGE_ID_MESSAGE);
    }
    const resolvePath = resolve_posix_path_1.ResolvePosixPath(exports.APP_DIR);
    const gnuSpawner = gnu_spawner_1.GnuSpawner(Object.assign({ resolvePath }, spawner_base_1.SpawnerBase(translate)));
    return Object.assign(Object.assign({}, gnuSpawner), { rimraf(path) {
            if (!path || resolvePath(path) === resolvePath()) {
                throw new Error('Refusing to delete whole directory because it is mirrored');
            }
            return gnuSpawner.rimraf(path);
        } });
    function translate(cmd) {
        const args = [
            'run',
            '--rm',
            '--privileged',
            '--interactive',
            '--volume',
            `${process.cwd()}:${resolvePath()}`,
        ];
        if (!cmd.superuser) {
            args.push('--user', `${process.getuid()}:${process.getgid()}`);
        }
        if (cmd.expose5000) {
            if (environment_1.ALWAYSAI_OS_PLATFORM === 'linux') {
                args.push('--network=host');
            }
            else {
                args.push('--publish', '127.0.0.1:5000:5000/tcp');
            }
        }
        // Note: We do not fully support docker spawner except on Linux
        if (environment_1.ALWAYSAI_OS_PLATFORM !== 'win32') {
            args.push('--volume', '/dev:/dev');
        }
        if (cmd.tty) {
            args.push('--tty');
        }
        if (cmd.targetHardware === 'nvidia') {
            args.push('--runtime=nvidia');
            args.push('--ipc=host');
            args.push('--volume');
            args.push('/tmp/argus_socket:/tmp/argus_socket');
        }
        args.push('--workdir', resolvePath(cmd.cwd));
        args.push(dockerImageId, cmd.exe);
        if (cmd.args) {
            args.push(...cmd.args);
        }
        const translated = {
            exe: 'docker',
            args,
            input: cmd.input,
        };
        return translated;
    }
}
exports.DockerSpawner = DockerSpawner;
//# sourceMappingURL=docker-spawner.js.map