"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ora = require("ora");
const audit_1 = require("./audit");
const environment_1 = require("../environment");
function Spinner(message) {
    audit_1.audit(`Spinner: ${message}`);
    let spinner;
    if (environment_1.NODE_ENV === 'test') {
        spinner = {
            fail() { },
            succeed() { },
            warn() { },
            setMessage() { },
        };
    }
    else {
        const oraSpinner = ora({ text: message, discardStdin: false }).start();
        spinner = {
            fail(message) {
                oraSpinner.fail(message);
            },
            warn(message) {
                oraSpinner.warn(message);
            },
            succeed(message) {
                oraSpinner.succeed(message);
            },
            setMessage(message) {
                oraSpinner.text = message;
            },
        };
    }
    return spinner;
}
exports.Spinner = Spinner;
//# sourceMappingURL=spinner.js.map