"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const t = require("io-ts");
const config_nodejs_1 = require("@alwaysai/config-nodejs");
const alwayscli_1 = require("@alwaysai/alwayscli");
const KeyMirror = require("keymirror");
const constants_1 = require("../constants");
exports.SystemId = KeyMirror({
    local: null,
    development: null,
    qa: null,
    production: null,
});
exports.SYSTEM_IDS = Object.keys(exports.SystemId);
const props = {
    systemId: t.keyof(exports.SystemId),
};
const codec = t.partial(props);
const CLI_JSON_FILE_NAME = 'alwaysai.cli.json';
const path = path_1.join(config_nodejs_1.ALWAYSAI_CONFIG_DIR, CLI_JSON_FILE_NAME);
const cliJsonFile = config_nodejs_1.ConfigFile({
    path,
    codec,
    ENOENT: {
        code: alwayscli_1.CLI_TERSE_ERROR,
        message: `File not found ${CLI_JSON_FILE_NAME}. Run command "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME} config set" to set configuration values.`,
    },
    initialValue: {},
});
function setSystemId(systemId) {
    return cliJsonFile.update(json => {
        json.systemId = systemId;
    });
}
exports.setSystemId = setSystemId;
function getSystemId() {
    const maybeConfig = cliJsonFile.readIfExists();
    const systemId = maybeConfig && maybeConfig.systemId ? maybeConfig.systemId : 'production';
    return systemId;
}
exports.getSystemId = getSystemId;
//# sourceMappingURL=system-id.js.map