import { CliTerseError } from '@alwaysai/alwayscli';
import { isAbsolute, join } from 'path';
import { existsSync } from 'fs';
import { ALWAYSAI_HOME, ALWAYSAI_OS_PLATFORM } from '../environment';

import { JsSpawner } from '../util/spawner/js-spawner';
import { runWithSpinner } from '../util/run-with-spinner';
import {
  VENV,
  PYTHON_REQUIREMENTS_FILE_NAME,
  ALWAYSAI_DESKTOP_SOFTWARE_NAME,
} from '../constants';
import { appInstallPreliminaryStepsComponent } from './app-install-preliminary-steps-component';
import { appInstallModelsComponent } from './app-install-models-component';
import { run } from '../util/spawner-base/run';
import { VenvExecutablesDirectoryName } from '../util/venv-executables-directory-name';

export async function appInstallComponent(props: { yes: boolean }) {
  const { yes } = props;

  if (
    (!ALWAYSAI_HOME || !isAbsolute(ALWAYSAI_HOME)) &&
    ALWAYSAI_OS_PLATFORM !== 'darwin'
  ) {
    throw new CliTerseError(
      `This command requires that ALWAYSAI_HOME is set in your environment to the absolute path of your ${ALWAYSAI_DESKTOP_SOFTWARE_NAME} installation`,
    );
  }

  await appInstallPreliminaryStepsComponent({ yes });

  await appInstallModelsComponent(JsSpawner());

  if (!existsSync(join(VENV, VenvExecutablesDirectoryName()))) {
    // check platform win or mac
    // if win
    const pythonExecutablePath =
      ALWAYSAI_OS_PLATFORM === 'win32'
        ? join(ALWAYSAI_HOME || '', 'resources', 'app', 'python35', 'python')
        : join(
            '/Applications',
            'alwaysAI.app',
            'Contents',
            'Resources',
            'app',
            'Python',
            'bin',
            'python3',
          );
    // if mac

    await runWithSpinner(
      run,
      [
        {
          exe: pythonExecutablePath,
          args: ['-m', VENV, '--system-site-packages', VENV],
          cwd: '.',
        },
      ],
      'Install python virtual environment',
    );
  }

  if (existsSync(PYTHON_REQUIREMENTS_FILE_NAME)) {
    await runWithSpinner(
      run,
      [
        {
          exe: join(VENV, VenvExecutablesDirectoryName(), 'pip'),
          args: ['install', '--requirement', PYTHON_REQUIREMENTS_FILE_NAME],
        },
      ],
      'Install python dependencies',
    );
  }
}
