import { SshSpawner } from '../util/spawner/ssh-spawner';
import { Spinner } from '../util/spinner';
import { confirmPromptComponent } from './confirm-prompt-component';
import { CliTerseError } from '@alwaysai/alwayscli';

export async function cleanTargetDirectoryComponent(props: {
  yes: boolean;
  targetHostname: string;
  targetPath: string;
}) {
  const { yes, targetHostname, targetPath } = props;
  let cleanDir = true;
  if (!yes) {
    cleanDir = await confirmPromptComponent({
      message: `Are you sure you want to delete the outdated target directory (${targetHostname}:${targetPath}) and redeploy the updated app`,
    });
  }

  if (cleanDir) {
    const spinner = Spinner('Delete target directory');
    try {
      const spawner = SshSpawner({
        targetHostname: props.targetHostname,
        targetPath: props.targetPath,
      });

      await spawner.sanatizedrimraf();
      spinner.succeed();
    } catch (exception) {
      spinner.fail();
      throw exception;
    }
  } else {
    throw new CliTerseError('Operation canceled by user');
  }
}
