import { spawn } from 'child_process';

import { Cmd } from '../spawner/types';

import signalExit = require('signal-exit');

import rKill = require('tree-kill');

import { CliTerseError } from '@alwaysai/alwayscli';

import { ALWAYSAI_OS_PLATFORM } from '../../environment';

export async function runForeground(cmd: Cmd) {
  const childProcess = spawn(cmd.exe, cmd.args || [], {
    cwd: cmd.cwd,
    stdio: 'inherit',
  });

  // Kill child when parent exits
  signalExit(() => {
    if (ALWAYSAI_OS_PLATFORM === 'darwin') {
      childProcess.kill('SIGINT');
      // ensures the main process gets killed by the correct signal - this will only activate with a ctrl + c
      // when it hits the siginit it will then activate the on exit signal and finish
      process.on('SIGINT', () => {
        rKill(childProcess.pid, 'SIGINT', (error?: Error | undefined) => {
          if (error) {
            throw new CliTerseError(
              `Failed to kill child process {error.name} {error.message}`,
            );
          }
        });
      });
    } else {
      childProcess.kill();
    }
  });

  return await new Promise<number | undefined>((resolve, reject) => {
    childProcess.on('error', err => {
      reject(err);
    });

    childProcess.on('exit', code => {
      if (code) {
        resolve(code);
      } else {
        resolve();
      }
    });
  });
}
